generate_initial_session_keys

Function generate_initial_session_keys 

pub fn generate_initial_session_keys<Block, T>(
    client: Arc<T>,
    at: &BlockId<Block>,
    seeds: Vec<String>,
) -> Result<(), ApiErrorFor<T, Block>>
where Block: BlockT, T: ProvideRuntimeApi<Block>, T::Api: SessionKeys<Block>,
Generate the initial session keys with the given seeds, at the given block and store them in the client’s keystore.