pub trait SessionKeys<Block: BlockT>: Core<Block> {
// Provided methods
fn generate_session_keys(
&self,
__runtime_api_at_param__: &BlockId<Block>,
seed: Option<Vec<u8>>,
) -> Result<Vec<u8>, Self::Error> { ... }
fn generate_session_keys_with_context(
&self,
__runtime_api_at_param__: &BlockId<Block>,
context: ExecutionContext,
seed: Option<Vec<u8>>,
) -> Result<Vec<u8>, Self::Error> { ... }
fn decode_session_keys(
&self,
__runtime_api_at_param__: &BlockId<Block>,
encoded: Vec<u8>,
) -> Result<Option<Vec<(Vec<u8>, KeyTypeId)>>, Self::Error> { ... }
fn decode_session_keys_with_context(
&self,
__runtime_api_at_param__: &BlockId<Block>,
context: ExecutionContext,
encoded: Vec<u8>,
) -> Result<Option<Vec<(Vec<u8>, KeyTypeId)>>, Self::Error> { ... }
}Expand description
Session keys runtime api.
Provided Methods
Sourcefn generate_session_keys(
&self,
__runtime_api_at_param__: &BlockId<Block>,
seed: Option<Vec<u8>>,
) -> Result<Vec<u8>, Self::Error>
fn generate_session_keys( &self, __runtime_api_at_param__: &BlockId<Block>, seed: Option<Vec<u8>>, ) -> Result<Vec<u8>, Self::Error>
Generate a set of session keys with optionally using the given seed. The keys should be stored within the keystore exposed via runtime externalities.
The seed needs to be a valid utf8 string.
Returns the concatenated SCALE encoded public keys.
Sourcefn generate_session_keys_with_context(
&self,
__runtime_api_at_param__: &BlockId<Block>,
context: ExecutionContext,
seed: Option<Vec<u8>>,
) -> Result<Vec<u8>, Self::Error>
fn generate_session_keys_with_context( &self, __runtime_api_at_param__: &BlockId<Block>, context: ExecutionContext, seed: Option<Vec<u8>>, ) -> Result<Vec<u8>, Self::Error>
Generate a set of session keys with optionally using the given seed. The keys should be stored within the keystore exposed via runtime externalities.
The seed needs to be a valid utf8 string.
Returns the concatenated SCALE encoded public keys.