pub fn generate_initial_session_keys<Block, T>(
client: Arc<T>,
at: &BlockId<Block>,
seeds: Vec<String>,
) -> Result<(), ApiErrorFor<T, Block>>Expand description
Generate the initial session keys with the given seeds, at the given block and store them in the client’s keystore.